#-------------------------------------------------------------------------------
#   Licensed Materials - Property of IBM
#
#   5724-T01 5724-S98
#
#    Copyright IBM Corp. 2003, 2010. All Rights Reserved.
#
#   US Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-------------------------------------------------------------------------------
package UserConfig;

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();
use AudLog;

#-------------------------------------------------------------------------------
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#-------------------------------------------------------------------------------

#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------

my @rules = 
(
#-------------------------------------------------------------------------------
# START: Hierarchy post parser
#-------------------------------------------------------------------------------

    # Rename DATE to ENDDATE and TIME to ENDTIME
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename DATE to ENDDATE and TIME to ENDTIME',
        INPUT_FILE_DESCRIPTION => ['^.+-#-(BTS|CHAN|FRL|NSE|NSVC|PCU|PTPPKF|TGTBTS|TRX)-#-I\.pif$'],
        HEADER_COUNTERS_OP     => sub
        {
            my $h_ref = shift;
            
            # Rename DATE to ENDDATE
            if ( exists $h_ref->{DATE} )
            {
                $h_ref->{ENDDATE} = $h_ref->{DATE};
                $h_ref->{DATE} = "";
            }
            
            # Rename TIME to ENDTIME
            if ( exists $h_ref->{TIME} )
            {
                $h_ref->{ENDTIME} = $h_ref->{TIME};
                $h_ref->{TIME} = "";
            }
            return 0;
        },
        DATA_COUNTERS_OP       => sub
        {
            my $c_ref = shift;
            
            # Remove counters with <NULL> values
            foreach my $cname ( keys %$c_ref ) {
                if ( $c_ref->{"$cname"} =~ /\<(NULL|null|Null)\>/ ) {
                    $c_ref->{"$cname"} = "";
                }
            }
            return 0;
        },
        FILENAME_SUFFIX            => 'RDT',
        PRODUCE_PIF                => 'True',
    },
    
    {
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Count the number of TRXs for each BTS',
        INPUT_FILE_DESCRIPTION  => ['^.+-#-TRX-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [ qw(BSC BTSM BTS) ],       
        NON_ADDITIVE_COUNTERS   => [ qw(BSC BTSM BTS TRX TRXFREQ NAME)],
        OUTPUT_BLOCK_NAME       => 'TRX',
        PRODUCE_PIF             => 'True',       
    },

    {      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert the number of TRXs for each BTS',
        INPUT_FILE_DESCRIPTION  => ['^.+-#-BTS-#-I-#-RDT\.pif$'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC','BTSM','BTS'],
        INFO_FILE_DESCRIPTION   => ['^.+-#-TRX-#-I-#-TRX-#-A\.pif$'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC','BTSM','BTS'],        
        REDUNDANT_DATA_COUNTERS => [],
        ONLY_INSERT             => ['TRX_NUM_IN_SUM'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
        REMOVE_INFO_FILES       => 'True',
    },
	
    {
        RULE_TYPE               => 'COUNT_ROWS',
        RULE_DESC               => 'Count the number of each CHTYPE for each BTS',
        INPUT_FILE_DESCRIPTION  => '^(.+)-#-BTS-#-I-#-RDT-#-S\.pif$',
        INPUT_FILE_KEYS         => [ qw(BSC BTSM BTS) ],
        COUNT_FILE_DESCRIPTION  => '^(.+)-#-CHAN-#-I\.pif$',
        COUNT_FILE_KEYS         => [ qw(BSC BTSM BTS) ],
        COUNTER_TO_COUNT        => 'CHTYPE',
        COUNTER_VALUES_TO_MATCH => [ qw(MBCCHC TCHSD TCHF_HLF SDCCH MAINBCCH) ],
        OUTPUT_COUNTER_NAMES    => [ qw(CHTYPE_MBCCHC CHTYPE_TCHSD CHTYPE_TCHF_HLF CHTYPE_SDCCH CHTYPE_MAINBCCH) ],
        DEFAULT_NULL_VALUE      => "",
        PRODUCE_PIF             => 'True',
        OUTPUT_FORMAT           => 0,
    },
   
    # Output CREATEBTS blocks finally
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename counters for BTS',
        INPUT_FILE_DESCRIPTION => ['^.+-#-BTS-#-I-#-RDT-#-S-#-CR\.pif$'],
        DATA_COUNTERS_OP           => sub
        {
            my $c_ref = shift;
            
            # Rename TRX_NUM_IN_SUM to TRX_NUM
            if ( exists $c_ref->{TRX_NUM_IN_SUM} )
            {
                $c_ref->{TRX_NUM} = $c_ref->{TRX_NUM_IN_SUM};
                $c_ref->{TRX_NUM_IN_SUM} = "";
            }
            
            # Remove double quotes from CELLGLID values
            if ( exists $c_ref->{CELLGLID} )
            {
                $c_ref->{CELLGLID} =~ s/\"//g;
            }
            return 0;
        },
        FILENAME_SUFFIX            => 'PL',
        PRODUCE_PIF                => 'True',
        OUTPUT_FORMAT              => 'LIF_Writer',
    },
   
    # Output CREATETRX, CREATECHAN and CREATEPTPPKF blocks finally
    {      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert CI and LAC for TRX, CHAN and PTPPKF',
        INPUT_FILE_DESCRIPTION  => ['^(.+)-#-(TRX|CHAN|PTPPKF)-#-I-#-RDT\.pif$'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC','BTSM','BTS'],
        INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I-#-RDT-#-S-#-CR-#-PL\.pif$'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC','BTSM','BTS'],        
        REDUNDANT_DATA_COUNTERS => [],
        ONLY_INSERT             => ['CI','LAC'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
    },
   
    # Output CREATENSVC blocks finally
    {      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert NMO for NSVC',
        INPUT_FILE_DESCRIPTION  => ['^(.+)-#-NSVC-#-I-#-RDT\.pif$'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC','NSVC'],
        INFO_FILE_DESCRIPTION   => ['^.+-#-NSE-#-I\.pif$'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC','NSE'],    
        REDUNDANT_DATA_COUNTERS => [],
        ONLY_INSERT             => ['NMO','NSEI'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 0,
        REMOVE_INFO_FILES       => 'True',
        OUTPUT_FORMAT           => 'LIF_Writer',
    },
	
	# Output CREATEFRL blocks finally
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Calculate CIR for FRL',
        INPUT_FILE_DESCRIPTION => ['^.+-#-FRL-#-I-#-RDT\.pif$'],                          
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			my @timeslot = split("&",$c_ref->{GTS});
			$c_ref->{CIR} = ($#timeslot + 1) * 64;
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 0,
		OUTPUT_FORMAT              => 'LIF_Writer',
    },	

	# Output CREATETGTBTS blocks finally
	{
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Remove double quotes from CELLGLID values in TGTBTS',
        INPUT_FILE_DESCRIPTION => ['^.+-#-TGTBTS-#-I-#-RDT\.pif$',],
        DATA_COUNTERS_OP           => sub
        {
            my $c_ref = shift;
            
            if ( exists $c_ref->{CELLGLID} )
            {
                $c_ref->{CELLGLID} =~ s/\"//g;
            }
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 0,
		OUTPUT_FORMAT              => 'LIF_Writer',
    },

#-------------------------------------------------------------------------------
# END: Hierarchy post parser
#-------------------------------------------------------------------------------

#-------------------------------------------------------------------------------
# START: Performance post parser
#-------------------------------------------------------------------------------

#-------------------------------------------------------------------------------
# SCANTRAU & SCANTRAU_HIGH_INTEGRATED, Generate LIF
#-------------------------------------------------------------------------------

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of TEMP_TRAU',
		INPUT_FILE_DESCRIPTION  => ['^(TEMP_TRAU-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID TRAU_ID) ],
		OUTPUT_BLOCK_NAME       => 'TEMP_TRAU',
		OUTPUT_FILENAME_START   => 'TEMP_TRAU',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
	},
	
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Assign blockname for TEMP_TRAU',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_TRAU-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J.pif$'],                                   
        DATA_COUNTERS_OP        => sub
        {
            my $d_ref = shift;
			
			my %sorted1;
			my %sorted2;
			my @similar1;
			my @similar2;
			my $block;
			foreach my $element (keys %{$d_ref})
			{
				$element =~ /(\w+_\d+)/;
				my $name = $1;
				$element =~ /\w+_(\d+)/;
				my $num = $1;
				if($d_ref->{$element} ne '')
				{
					if($element =~ /^TRAUMSBPRCLD_\d+$/)
					{
						LogMess("element:".$d_ref->{$element},1);
						$sorted1{$num} = $name;
					}
					if($element =~ /^TRAUSMACPRCLD_\d+$/)
					{	
						$sorted2{$num} = $name;
					}
				}
			}
			
			foreach my $element (sort { $a <=> $b }(keys (%sorted1)))
			{	push @similar1, $sorted1{$element};	}
			foreach my $element (sort { $a <=> $b }(keys (%sorted2)))
			{	push @similar2, $sorted2{$element};	}
			
			$similar1[0] =~ /TRAUMSBPRCLD_(\d+)/;
			my $minnum1 = $1;
			$similar1[$#similar1] =~ /TRAUMSBPRCLD_(\d+)/;
			my $maxnum1 = $1;
					
			$similar2[0] =~ /TRAUSMACPRCLD_(\d+)/;
			my $minnum2 = $1;
			$similar2[$#similar2] =~ /TRAUSMACPRCLD_(\d+)/;
			my $maxnum2 = $1;
			
			if(($minnum2 >= 1) && ($maxnum2 <=4) && (($#similar1+1)==4))
			{
				if(($minnum1 >= 1) && ($maxnum1 <= 24) && (($#similar1+1)==24))
				{	$d_ref->{block}='NORMAL';	}	#NORMAL is SCANTRAU
				elsif((($minnum1 >= 1) && ($maxnum1 <=40) && (($#similar1+1)==40)) || (($minnum1 >= 1) && ($maxnum1 <=54) && (($#similar1+1)==54)))
				{	$d_ref->{block}='HIGH';	}	#HIGH is SCANTRAU_HIGH_INTEGRATED
				else
				{	$d_ref->{block}='NORMAL';	}
			}
			elsif(($minnum2 >= 1) && ($maxnum2 <=8) && (($#similar2+1)==8))
			{	$d_ref->{block}='HIGH';	}
			elsif(($minnum1 >= 1) && ($maxnum1 <= 24) && (($#similar1+1)==24))
			{	$d_ref->{block}='NORMAL';	}
			elsif((($minnum1 >= 1) && ($maxnum1 <=40) && (($#similar1+1)==40)) || (($minnum1 >= 1) && ($maxnum1 <=54) && (($#similar1+1)==54)))
			{	$d_ref->{block}='HIGH';	}
			else
			{	$d_ref->{block}='NORMAL';	}
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },
	
	{
	    RULE_TYPE                   => 'FILE_SPLIT',
	    RULE_DESCRIPTION            => 'Split TEMP_TRAU according to blocks',
	    INPUT_FILE_DESCRIPTION      => '^TEMP_TRAU-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ\.pif$',
		COUNTERS_USED_TO_SPLIT_FILE => {
				block => '(.*)',
		},
		SPLIT_COUNTERS_ORDER         => [ qw(block)],
	    PRODUCE_PIF                 => 'True',
	},

	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate PIF and LIF for SCANTRAU',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_TRAU-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ-#-NORMAL-#-FS\.pif$',],
		OUTPUT_FILENAME_START   => 'SCANTRAU',
		OUTPUT_BLOCK_NAME          => 'SCANTRAU',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT           => 'LIF_Writer',
    },

	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate PIF and LIF for SCANTRAU_HIGH_INTEGRATED',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_TRAU-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ-#-HIGH-#-FS\.pif$',],
		OUTPUT_FILENAME_START   => 'SCANTRAU_HIGH_INTEGRATED',
		OUTPUT_BLOCK_NAME          => 'SCANTRAU_HIGH_INTEGRATED',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT           => 'LIF_Writer',
    },
#------------------------------------------------------------------------------------------------------------------------------
# EBSC, EBSC_BASIC, EBSC_EXTENDED, Generate LIF
#------------------------------------------------------------------------------------------------------------------------------

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pifs of TEMP_EBSC',
		INPUT_FILE_DESCRIPTION  => ['^(TEMP_EBSC-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$',],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID) ],
		OUTPUT_BLOCK_NAME       => 'TEMP_EBSC',
		OUTPUT_FILENAME_START   => 'TEMP_EBSC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
	},
	
	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'Split TEMP_EBSC according to counters',
        INPUT_FILE_DESCRIPTION => ['^TEMP_EBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$'],
        SPLIT_CNAMES => {
			'EBSC' => ['^CNSPRCLD_\d+$'],	#SCANBSC_EBSC
			'EBSC_X' => ['^BSCPRCLD_\d+$'],	#SCANBSC_EBSC_BASIC or SCANBSC_EBSC_EXTENDED
        },
        ONLY_INSERT  => [ qw(BSS_ID BSC_ID BTSM_ID) ],
        PRODUCE_PIF  => 'True',        
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'GENERATE PIF and LIF for SCANBSC_EBSC',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_EBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-EBSC-#-FSC\.pif$',],
        OUTPUT_FILENAME_START   => 'EBSC',
		OUTPUT_BLOCK_NAME          => 'SCANBSC_EBSC',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT           => 'LIF_Writer',
    },

	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Assign blockname for TEMP_EBSC_X',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_EBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-EBSC_X-#-FSC\.pif$'],
        DATA_COUNTERS_OP        => sub
        {
            my $d_ref = shift;
			my %sorted1;
			my @similar1;
			my $block;
			foreach my $element (sort (keys %{$d_ref}))
			{
				$element =~ /(\w+_\d+)/;
				my $name = $1;
				$element =~ /\w+_(\d+)/;
				my $num = $1;
				if($d_ref->{$element} ne '')
				{
					if($element =~ /^BSCPRCLD_\d+$/)
					{	
						$sorted1{$num} = $name;
					}
				}
			}
			foreach my $element (sort { $a <=> $b }(keys (%sorted1)))
			{	push @similar1, $sorted1{$element};	}
			$similar1[0] =~ /BSCPRCLD_(\d+)/;
			my $minnum1 = $1;
			$similar1[$#similar1] =~ /BSCPRCLD_(\d+)/;
			my $maxnum1 = $1;
				
			if(($minnum1 >= 8) && ($maxnum1 <= 98) && (($#similar1+1) == 74))
			{	$block='BASIC'; } #SCANBSC_EBSC_BASIC
			elsif(($minnum1 >= 8) && ($maxnum1 <= 98) && (($#similar1+1) == 78))
			{	$block='EXTENDED'; } #SCANBSC_EBSC_EXTENDED
			
			$d_ref->{block} = $block;
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },

	{
	    RULE_TYPE                   => 'FILE_SPLIT',
	    RULE_DESCRIPTION            => 'Split TEMP_EBSC_X according to blockname',
	    INPUT_FILE_DESCRIPTION      => ['^TEMP_EBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-EBSC_X-#-FSC-#-PZ\.pif$', ],
		COUNTERS_USED_TO_SPLIT_FILE => {
				block => '(.*)',
		},
		SPLIT_COUNTERS_ORDER         => [ qw(block)],
	    PRODUCE_PIF                 => 'True',
	},
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate PIF and LIF for SCANBSC_EBSC_EXTENDED',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_EBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-EBSC_X-#-FSC-#-PZ-#-EXTENDED-#-FS\.pif$', ],
        OUTPUT_FILENAME_START   => 'EBSC_EX',
		OUTPUT_BLOCK_NAME          => 'SCANBSC_EBSC_EXTENDED',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT           => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate PIF and LIF for SCANBSC_EBSC_BASIC',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_EBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-EBSC_X-#-FSC-#-PZ-#-BASIC-#-FS\.pif$',],
        OUTPUT_FILENAME_START   => 'EBSC_BASIC',
		OUTPUT_BLOCK_NAME          => 'SCANBSC_EBSC_BASIC',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT           => 'LIF_Writer',
    },

#------------------------------------------------------------------------------------------------------------------------------
# Insert CI
#------------------------------------------------------------------------------------------------------------------------------

    {      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert CI (Cell Id) from BTS hierarchy data',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-I\.pif$',
                                    '^SCANCHAN-#-.+-#-I\.pif$',
									'^SCANBTSIHO-#-.+-#-I\.pif$',
									'^SCANBTSOHOI-#-.+-#-I\.pif$'
                                   ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID', 'BTSM_ID','BTS_ID'],
        #INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I\.pif$'],
		INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I-#-RDT-#-S-#-CR-#-PL\.pif$'], #alm00211426
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC', 'BTSM','BTS'],
		REDUNDANT_DATA_COUNTERS => ['BSC', 'BTSM','BTS'],
        ONLY_INSERT             => ['CI'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
    },
	
	{      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert CI (Cell Id) from BTS hierarchy data',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSOHON-#-.+-#-I\.pif$',
                                    '^SCANBTSOHOS-#-.+-#-I\.pif$',
                                   ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID', 'BTSM_ID','BTS_ID'],
        #INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I\.pif$'],
		INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I-#-RDT-#-S-#-CR-#-PL\.pif$'], #alm00211426
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC','BTSM','BTS'],
		REDUNDANT_DATA_COUNTERS => ['BTS'],
        ONLY_INSERT             => ['CI'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
    },
	
#-------------------------------------------------------------------------------
# Insert ADJ_CI
#-------------------------------------------------------------------------------
	{      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert ADJ_CI (Cell Id) from BTS hierarchy data',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSIHO-#-.+-#-I-#-S\.pif$',
                                    '^SCANBTSOHOI-#-.+-#-I-#-S\.pif$',
                                   ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['ADJ_BSC_ID', 'ADJ_BTSM_ID','ADJ_BTS_ID'],
        #INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I\.pif$'],
		INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I-#-RDT-#-S-#-CR-#-PL\.pif$'], #alm00211426
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC', 'BTSM','BTS'],
		REDUNDANT_DATA_COUNTERS => ['BSC', 'BTSM','BTS'],
        ONLY_INSERT             => ['ADJ_CI'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
    },
	
	{      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert ADJ_CI (Cell Id) from TGTBTS hierarchy data',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSOHON-#-.+-#-I-#-S\.pif$'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['ADJ_TGTBTS_NO'],
        INFO_FILE_DESCRIPTION   => ['^.+-#-TGTBTS-#-I\.pif$'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['TGTBTS'],
		REDUNDANT_DATA_COUNTERS => ['TGTBTS'],
        ONLY_INSERT             => ['ADJ_CI'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
    },

#-------------------------------------------------------------------------------
# Insert CELLTYPE, CONCELL, CI, PCUN
#-------------------------------------------------------------------------------	
	
	{      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert CELLTYPE, CONCELL, CI from BTS hierarchy data',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_BTS-#-.+-#-I\.pif$',
									'^SCANBTSE-#-.+-#-I\.pif$',
									'^SCANBTS-#-.+-#-I\.pif$',
									'^SCANBTS_STANDARD-#-.+-#-I\.pif$',
                                    '^SCANGPRS-#-.+-#-I\.pif$',
                                   ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID','BTS_ID','BTSM_ID'],
        #INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I\.pif$'],
		INFO_FILE_DESCRIPTION   => ['^.+-#-BTS-#-I-#-RDT-#-S-#-CR-#-PL\.pif$'], #alm00211426
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC','BTS','BTSM'],
		REDUNDANT_DATA_COUNTERS => ['BTS'],
        ONLY_INSERT             => ['CI', 'CONCELL', 'CELLTYPE'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
    },

	{      
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert PCUN from PTPPKF hierarchy data',
        INPUT_FILE_DESCRIPTION  => ['^SCANGPRS-#-.+-#-I-#-S\.pif$',],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
        NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID','BTSM_ID', 'BTS_ID', 'PTPPKF_ID'],
        INFO_FILE_DESCRIPTION   => ['^.+-#-PTPPKF-#-I\.pif$'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => [],
        NAMES_USED_TO_ID_INFORMATION => ['BSC','BTSM', 'BTS', 'PTPPKF'],
		REDUNDANT_DATA_COUNTERS => ['BTSM', 'BTS', 'PTPPKF'],
        ONLY_INSERT             => ['PCUN'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
    },

	
#---------------------------------------------------------------------
# START: Cleaning up INFOINSERT PIFs
#---------------------------------------------------------------------
# The hierarchy data is optional, a JOIN rule is needed to join
# both initial data (non-inserted) and inserted data together.
# This provides a single execution path in the UserConfig in case
# the hierachy data is not present.
#---------------------------------------------------------------------
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANTRX blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANTRX-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID TRX_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANTRX',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANTRX',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANCHAN blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANCHAN-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID TRX_ID CHANNEL_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANCHAN',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANCHAN',
        PRODUCE_PIF                => 'True',
    },	
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTSOHOS blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTSOHOS-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_FDD_NO ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTSOHOS',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTSOHOS',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTSIHO blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTSIHO-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S|I-#-S-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_BTSM_ID ADJ_BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTSIHO',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTSIHO',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTSOHOI blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTSOHOI-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S|I-#-S-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_BTSM_ID ADJ_BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTSOHOI',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTSOHOI',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTSOHON blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTSOHON-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S|I-#-S-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_TGTBTS_NO ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTSOHON',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTSOHON',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for TEMP_BTS blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(TEMP_BTS-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?)(?:I|I-#-S)\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'TEMP_BTS',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'TEMP_BTS',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTSE blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTSE-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S)\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTSE',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTSE',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTS blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTS-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S)\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTS',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTS',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANBTS_STANDARD blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANBTS_STANDARD-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S)\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANBTS_STANDARD',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANBTS_STANDARD',
        PRODUCE_PIF                => 'True',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join initial PIFs and infoinserted PIFs for SCANGPRS blocks together',
        INPUT_FILE_DESCRIPTION     => [ '^(SCANGPRS-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?(?:I|I-#-S|I-#-S-#-S)\.pif$' ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID PTPPKF_ID) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START      => 'SCANGPRS',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_BLOCK_NAME          => 'SCANGPRS',
        PRODUCE_PIF                => 'True',
    },
	
	
	{
        RULE_TYPE              => 'PIF_REMOVE',
        RULE_DESC              => 'Remove all initial PIFs of blocks that were joined',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-I\.pif$',
									'^SCANCHAN-#-.+-#-I\.pif$',
                                    '^SCANBTSOHON-#-.+-#-I\.pif$', 
									'^SCANBTSOHOS-#-.+-#-I\.pif$',
									'^TEMP_BTS-#-.+-#-I\.pif$',
									'^SCANBTSE-#-.+-#-I\.pif$',
									'^SCANBTS-#-.+-#-I\.pif$',
									'^SCANBTS_STANDARD-#-.+-#-I\.pif$',
									'^SCANGPRS-#-.+-#-I\.pif$', 
									'^SCANBTSIHO-#-.+-#-I\.pif$',
									'^SCANBTSOHOI-#-.+-#-I\.pif$',
                                   ],
    },

#-------------------------------------------------------------------------------
# Set default CI & ADJ_CI
#-------------------------------------------------------------------------------	
	
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Set CI if not found',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-J\.pif$',
                                    '^SCANCHAN-#-.+-#-J\.pif$',
                                    '^SCANBTSOHOS-#-.+-#-J\.pif$',
									'^SCANGPRS-#-.+-#-J\.pif$',
                                   ],                                   
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
            
			if ((not (exists $c_ref->{CI})) || ($c_ref->{CI} eq ""))
			{	$c_ref->{CI} = "bts-$c_ref->{BSC_ID}-$c_ref->{BTSM_ID}-$c_ref->{BTS_ID}";	}
			
			#for SCANGPRS
			if ((exists $c_ref->{PCUN}) && ($c_ref->{PCUN} eq ""))
			{	$c_ref->{PCUN} = 'UNKNOWN';	}
			if ((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} eq ""))
			{	$c_ref->{CELLTYPE} = 'UNKNOWN';	}
			if ((exists $c_ref->{CONCELL}) && ($c_ref->{CONCELL} eq ""))
			{	$c_ref->{CONCELL} = 'UNKNOWN';	}
			
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },	
	
    {
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Set CI and ADJ_CI if not found',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSIHO-#-.+-#-J\.pif$',
									'^SCANBTSOHOI-#-.+-#-J\.pif$',
                                   ],                                   
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
            
			if ((not (exists $c_ref->{CI})) || ($c_ref->{CI} eq ""))
			{	$c_ref->{CI} = "bts-$c_ref->{BSC_ID}-$c_ref->{BTSM_ID}-$c_ref->{BTS_ID}";	}
			
			if ((not (exists $c_ref->{ADJ_CI})) || ($c_ref->{ADJ_CI} eq ""))
			{	$c_ref->{ADJ_CI} = "bts-$c_ref->{ADJ_BSC_ID}-$c_ref->{ADJ_BTSM_ID}-$c_ref->{ADJ_BTS_ID}";	}

            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },	
	
    {
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Set SI and ADJ_CI if not found',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSOHON-#-.+-#-J\.pif$',],                                   
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
            
			if ((not (exists $c_ref->{CI})) || ($c_ref->{CI} eq ""))
			{	$c_ref->{CI} = "bts-$c_ref->{BSC_ID}-$c_ref->{BTSM_ID}-$c_ref->{BTS_ID}";	}
			
			if ((not (exists $c_ref->{ADJ_CI})) || ($c_ref->{ADJ_CI} eq ""))
			{	$c_ref->{ADJ_CI} = "$c_ref->{ADJ_BSC_ID}-$c_ref->{ADJ_TGTBTS_ID}";	}
			
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },		

#-------------------------------------------------------------------------------
# Splitting BSC block
#-------------------------------------------------------------------------------
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANBSC',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBSC-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID TRAU_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANBSC',
		OUTPUT_FILENAME_START   => 'SCANBSC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'Split SCANBSC according to counters',
        INPUT_FILE_DESCRIPTION => ['^SCANBSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$'],
        SPLIT_CNAMES => {
		   #SCANBSC_MPCC=> [BSCPRCLD_1  BSCPRCLD_3]
		   'SCANBSC_MPCC' => ['^BSCPRCLD_[1-3]$'],
			#SCANBSC_TDPC =>[BSCPRCLD_4  BSCPRCLD_6]
			'SCANBSC_TDPC' => ['^BSCPRCLD_[4-6]$'],
			#SCANBSC_PPXU  =>[BSCPRCLD_7  BSCPRCLD_42]
			'SCANBSC_PPXU'  =>['(^BSCPRCLD_[7-9]$|^BSCPRCLD_[1-3][0-9]$|^BSCPRCLD_4[0-2]$)'],
        },
        ONLY_INSERT  => [ qw(BSS_ID BSC_ID BTSM_ID ENDDATE ENDTIME GRANULARITY) ],
        PRODUCE_PIF  => 'True',        
    },

	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANBSC_MPCC',
        INPUT_FILE_DESCRIPTION  => ['^SCANBSC-#-.+-#-J-#-SCANBSC_MPCC-#-FSC\.pif$',],
		OUTPUT_FILENAME_START   => 'SCANBSC_MPCC',
		OUTPUT_BLOCK_NAME          => 'SCANBSC_MPCC',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANBSC_TDPC',
        INPUT_FILE_DESCRIPTION  => ['^SCANBSC-#-.+-#-J-#-SCANBSC_TDPC-#-FSC\.pif$',],
		OUTPUT_FILENAME_START   => 'SCANBSC_TDPC',
		OUTPUT_BLOCK_NAME          => 'SCANBSC_TDPC',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANBSC_PPXU',
        INPUT_FILE_DESCRIPTION  => ['^SCANBSC-#-.+-#-J-#-SCANBSC_PPXU-#-FSC\.pif$',],
        OUTPUT_FILENAME_START   => 'SCANBSC_PPXU',
		OUTPUT_BLOCK_NAME          => 'SCANBSC_PPXU',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },

#-------------------------------------------------------------------------------
# Split the SCANCTRX block
#-------------------------------------------------------------------------------
	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'Split SCANCTRX according to counters',
        INPUT_FILE_DESCRIPTION => ['^SCANTRX-#-.+-#-J-#-PZ\.pif$'],
        SPLIT_CNAMES => {
		   #SCANCTRX_CRXLVQUU=> [CRXLEQTA_1  CRXLEQTA_64]
		   'SCANCTRX_CRXLVQUU' => ['(^CRXLEQTA_[1-9]$|^CRXLEQTA_[1-5][0-9]$|^CRXLEQTA_6[0-4]$)'],
			#SCANCTRX_CRXLVQUD =>[CRXLEQTA_65  CRXLEQTA_128]
			'SCANCTRX_CRXLVQUD' => ['(^CRXLEQTA_6[5-9]$|^CRXLEQTA_[7-9][0-9]$|^CRXLEQTA_1[0-1][0-9]$|^CRXLEQTA_12[0-8]$)'],
			#SCANCTRX_CRXLVTAU  =>[CRXLEQTA_129  CRXLEQTA_192]
			'SCANCTRX_CRXLVTAU'  =>['(^CRXLEQTA_129$|^CRXLEQTA_1[3-8][0-9]$|^CRXLEQTA_19[0-2]$)'],
			#SCANCTRX_SCANCTRX_CRXLVTAD  =>[CRXLEQTA_193  CRXLEQTA_256]
			'SCANCTRX_CRXLVTAD'  =>['(^CRXLEQTA_19[3-9]$|^CRXLEQTA_2[0-4][0-9]$|^CRXLEQTA_25[0-6]$)'],
			#SCANCTRX_CFERRXQU  =>[CRXLEQTA_257  CRXLEQTA_320]
			'SCANCTRX_CFERRXQU'  =>['(^CRXLEQTA_25[7-9]$|^CRXLEQTA_2[6-9][0-9]$|^CRXLEQTA_3[0-1][0-9]$|^CRXLEQTA_320$)'],
        },
        ONLY_INSERT  => [ qw(BSS_ID BSC_ID BTSM_ID BTS_ID TRX_ID CI ENDDATE ENDTIME GRANULARITY) ],
        PRODUCE_PIF  => 'True',        
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANCTRX_CRXLVQUU',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-J-#-PZ-#-SCANCTRX_CRXLVQUU-#-FSC\.pif$',],
		OUTPUT_BLOCK_NAME          => 'SCANCTRX_CRXLVQUU',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANCTRX_CRXLVQUD',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-J-#-PZ-#-SCANCTRX_CRXLVQUD-#-FSC\.pif$',],
		OUTPUT_BLOCK_NAME          => 'SCANCTRX_CRXLVQUD',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANCTRX_CRXLVTAU',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-J-#-PZ-#-SCANCTRX_CRXLVTAU-#-FSC\.pif$',],
		OUTPUT_BLOCK_NAME          => 'SCANCTRX_CRXLVTAU',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANCTRX_CRXLVTAD',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-J-#-PZ-#-SCANCTRX_CRXLVTAD-#-FSC\.pif$',],
		OUTPUT_BLOCK_NAME          => 'SCANCTRX_CRXLVTAD',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
    },
	
	{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Generate LIF for SCANCTRX_CFERRXQU',
        INPUT_FILE_DESCRIPTION  => ['^SCANTRX-#-.+-#-J-#-PZ-#-SCANCTRX_CFERRXQU-#-FSC\.pif$',],
		OUTPUT_BLOCK_NAME          => 'SCANCTRX_CFERRXQU',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
    },

#-------------------------------------------------------------------------------
# Set Blockname for SCANBTS family
#-------------------------------------------------------------------------------

    # Set BTS ID as CI and ADJ BTS ID as ADJ_CI if not found
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Set CELLTYPE and CI value',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSE-#-.+-#-J\.pif$',
									#'^SCANBTS-#-.+-#-J\.pif$',	#alm00216251
									'^SCANBTS_STANDARD-#-.+-#-J\.pif$',
                                   ],                                   

        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			
			if ((not (exists $c_ref->{CI})) || ($c_ref->{CI} eq ""))
			{	$c_ref->{CI} = "bts-$c_ref->{BSC_ID}-$c_ref->{BTSM_ID}-$c_ref->{BTS_ID}";	}
			
			if((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} ne ""))
			{
				if($c_ref->{CELLTYPE} =~ /STDCELL/)
				{	$c_ref->{CELLTYPE} = 0;	}
				elsif($c_ref->{CELLTYPE} =~ /CONCELL/)
				{	$c_ref->{CELLTYPE} = 1;	}
				elsif($c_ref->{CELLTYPE} =~ /EXTCELL/)
				{	$c_ref->{CELLTYPE} = 2;	}
			}
			
			if ((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} eq ""))
			{	$c_ref->{CELLTYPE} = 'UNKNOWN';	}	#to make the counter appear in the LIF
			if ((exists $c_ref->{CONCELL}) && ($c_ref->{CONCELL} eq ""))
			{	$c_ref->{CONCELL} = 'UNKNOWN';	}
			
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },
	
	#alm00216251
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Set CI value for SCANBTS',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTS-#-.+-#-J\.pif$'],                                   

        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			
			if ((not (exists $c_ref->{CI})) || ($c_ref->{CI} eq ""))
			{	$c_ref->{CI} = "bts-$c_ref->{BSC_ID}-$c_ref->{BTSM_ID}-$c_ref->{BTS_ID}";	}
			
			if((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} ne ""))
			{
				if($c_ref->{CELLTYPE} =~ /STDCELL/)
				{	$c_ref->{CELLTYPE} = 0;	}
				elsif($c_ref->{CELLTYPE} =~ /CONCELL/)
				{	$c_ref->{CELLTYPE} = 1;	}
				elsif($c_ref->{CELLTYPE} =~ /EXTCELL/)
				{	$c_ref->{CELLTYPE} = 2;	}
			}

			if ((exists $c_ref->{CONCELL}) && ($c_ref->{CONCELL} eq ""))
			{	$c_ref->{CONCELL} = 'UNKNOWN';	}
			
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },
	
    {
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Set CELLTYPE, CI value and assign blockname to TEMP_BTS',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_BTS-#-.+-#-J\.pif$', ],
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			my $block = "";
			
			if ((not (exists $c_ref->{CI})) || ($c_ref->{CI} eq ""))
			{	$c_ref->{CI} = "bts-$c_ref->{BSC_ID}-$c_ref->{BTSM_ID}-$c_ref->{BTS_ID}";	}
			
			if((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} ne ""))
			{
				if($c_ref->{CELLTYPE} =~ /STDCELL/)
				{	$c_ref->{CELLTYPE} = 0;	}
				elsif($c_ref->{CELLTYPE} =~ /CONCELL/)
				{	$c_ref->{CELLTYPE} = 1;	}
				elsif($c_ref->{CELLTYPE} =~ /EXTCELL/)
				{	$c_ref->{CELLTYPE} = 2;	}
			}

			my @keys = sort (keys %{$c_ref});
			for (my $i=0; $i<=($#keys + 1); $i++)
			{
				if($keys[$i] =~ /(^ATCHSMBS_[5-8]$|^MEBUSTCH_[5-6]$|^NAVTCH_[7-9]$|^NAVTCH_1[0-8]$|^NRDEFTCH_[7-9]$|^NRDEFTCH_1[0-8]$|^NRFLTCH_19$|^NRFLTCH_[2-4][0-9]$|^NRFLTCH_5[0-4]$|^TNTCHCL_[3-6]$)/)
				{	
					$block = 'CON'; 
					last;
				}
				elsif($keys[$i] =~ /(^ATCHSMBS_9$|^ATCHSMBS_1[0-2]$|^MEBUSTCH_[7-9]$|^MEBUSTCH_10$|^NAVTCH_19$|^NAVTCH_2[0-9]$|^NAVTCH_30$|^NRDEFTCH_19$|^NRDEFTCH_2[0-9]$|^NRDEFTCH_30$|^NRFLTCH_5[6-9]$|^NRFLTCH_[6-8][0-9]$|^NRFLTCH_90$|^TNTCHCL_[7-9]$|^TNTCHCL_10$)/)
				{	
					$block = 'EXT'; 
					last;
				}
				elsif($keys[$i] =~ /(^MEBUTSLY_3[7-9]$|^MEBUTSLY_[4-9][0-9]$|^MEBUTSLY_10[0-8]$)/)
				{
					if((exists $c_ref->{CONCELL}) && ($c_ref->{CONCELL} ne ""))
					{
						if($c_ref->{CONCELL} =~ /TRUE/)
						{	
							$block = 'CON';	#SCANBTS_CONCENTRIC
							last;
						}
						else
						{	
							$block = 'EXT';	#SCANBTS_EXTENDED
							last;							
						}
					}
					elsif((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} =~ /[1-2]/))
					{
						if($c_ref->{CELLTYPE} = 1)
						{	
							$block = 'CON';
							last;
						}
						elsif($c_ref->{CELLTYPE} = 2)
						{	
							$block = 'EXT';
							last;
						}
					}
					else
					{
						$block = 'CONEXT';	#output SCANBTS_CONCENTRIC and SCANBTS_EXTENDED blocks
						last;
					}
				}
				elsif($i ==($#keys + 1))
				{	$block = 'CONEXT';	}
			}
			$c_ref->{block} = $block;
			
			if ((exists $c_ref->{CELLTYPE}) && ($c_ref->{CELLTYPE} eq ""))
			{	$c_ref->{CELLTYPE} = 'UNKNOWN';	}
			if ((exists $c_ref->{CONCELL}) && ($c_ref->{CONCELL} eq ""))
			{	$c_ref->{CONCELL} = 'UNKNOWN';	}
			
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },
	
	{
	    RULE_TYPE                   => 'FILE_SPLIT',
	    RULE_DESCRIPTION            => 'Split TEMP_BTS according to blocks',
	    INPUT_FILE_DESCRIPTION      => '^TEMP_BTS-#-.+-#-J-#-PZ\.pif$',
		COUNTERS_USED_TO_SPLIT_FILE => {
				block => '(.*)',
		},
		SPLIT_COUNTERS_ORDER         => [ qw(block)],
	    PRODUCE_PIF                 => 'True',
	},

	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join for SCANBTS_CONCENTRIC LIF',
		INPUT_FILE_DESCRIPTION     => [ '^(TEMP_BTS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-CON-#-FS\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_FILENAME_START  => 'SCANBTS_CONCENTRIC',   
        OUTPUT_BLOCK_NAME      => 'SCANBTS_CONCENTRIC',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join for SCANBTS_EXTENDED LIF',
		INPUT_FILE_DESCRIPTION     => [ '^(TEMP_BTS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-EXT-#-FS\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_FILENAME_START  => 'SCANBTS_EXTENDED',   
        OUTPUT_BLOCK_NAME      => 'SCANBTS_EXTENDED',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },

	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join for SCANBTS_CONCENTRIC LIF',
		INPUT_FILE_DESCRIPTION     => [ '^(TEMP_BTS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-CONEXT-#-FS\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_FILENAME_START  => 'SCANBTS_CONCENTRIC_2',   
        OUTPUT_BLOCK_NAME      => 'SCANBTS_CONCENTRIC',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },
	
	{   
        RULE_TYPE                  => 'JOIN',
        RULE_DESC                  => 'Join for SCANBTS_EXTENDED LIF',
		INPUT_FILE_DESCRIPTION     => [ '^(TEMP_BTS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-CONEXT-#-FS\.pif$', ],
        COUNTERS_TO_JOIN_ON        => [ qw( BSC_ID BTSM_ID BTS_ID ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['ENDDATE','ENDTIME'],
        OUTPUT_FILENAME_START  => 'SCANBTS_EXTENDED_2',   
        OUTPUT_BLOCK_NAME      => 'SCANBTS_EXTENDED',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },

#---------------------------------------------------------------------------------------------------------------------
# Make MEBUSTCH counters to be available in SCANBTS
#---------------------------------------------------------------------------------------------------------------------
	
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Change the counter names for SCANBTS and generate LIF',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_BTS-#-.+-#-J-#-PZ-#-CON-#-FS\.pif$',
									'^TEMP_BTS-#-.+-#-J-#-PZ-#-CONEXT-#-FS\.pif$'
                                   ],   
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			if((exists $c_ref->{MEBUSTCH_3}) || (exists $c_ref->{MEBUSTCH_4}) || (exists $c_ref->{MEBUSTCH_5}) || (exists $c_ref->{MEBUSTCH_6}))
			{
				$c_ref->{MEBUSTCH_1} = $c_ref->{MEBUSTCH_3};
				$c_ref->{MEBUSTCH_2} = $c_ref->{MEBUSTCH_4};
				$c_ref->{MEBUSTCH_3} = $c_ref->{MEBUSTCH_5};
				$c_ref->{MEBUSTCH_4} = $c_ref->{MEBUSTCH_6};
			}
			#for debug purpose
			if ($c_ref->{block} eq 'CON')
			{	$c_ref->{block} = 'S_CON';	}			
			elsif ($c_ref->{block} eq 'CONEXT')
			{	$c_ref->{block} = 'S_CONEXT_CON';	}
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ_CON',
		OUTPUT_FILENAME_START  => 'SCANBTS', 
		OUTPUT_BLOCK_NAME          => 'SCANBTS',
		REDUNDANT_DATA_COUNTERS    => ['MEBUSTCH_5','MEBUSTCH_6'],
        PRODUCE_PIF                => 'True',
    },
	
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Change the counter names for SCANBTS and generate LIF',
        INPUT_FILE_DESCRIPTION  => ['^TEMP_BTS-#-.+-#-J-#-PZ-#-EXT-#-FS\.pif$',
									'^TEMP_BTS-#-.+-#-J-#-PZ-#-CONEXT-#-FS\.pif$'
                                   ],
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			if((exists $c_ref->{MEBUSTCH_7}) || (exists $c_ref->{MEBUSTCH_8}) || (exists $c_ref->{MEBUSTCH_9}) || (exists $c_ref->{MEBUSTCH_10}))
			{
				$c_ref->{MEBUSTCH_1} = $c_ref->{MEBUSTCH_7};
				$c_ref->{MEBUSTCH_2} = $c_ref->{MEBUSTCH_8};
				$c_ref->{MEBUSTCH_3} = $c_ref->{MEBUSTCH_9};
				$c_ref->{MEBUSTCH_4} = $c_ref->{MEBUSTCH_10};
			}
			#for debug purpose
			if ($c_ref->{block} eq 'EXT')
			{	$c_ref->{block} = 'S_EXT';	}
			elsif ($c_ref->{block} eq 'CONEXT')
			{	$c_ref->{block} = 'S_CONEXT_EXT';	}
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ_EXT',
		OUTPUT_FILENAME_START  => 'SCANBTS', 
		OUTPUT_BLOCK_NAME          => 'SCANBTS',
		REDUNDANT_DATA_COUNTERS    => ['MEBUSTCH_7','MEBUSTCH_8','MEBUSTCH_9','MEBUSTCH_10'],
        PRODUCE_PIF                => 'True',
    },
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Generate LIF for SCANBTS and Join SCANBTS files for BTS_AGG_TO_BSC accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(TEMP_BTS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-(?:CON|EXT|CONEXT)-#-FS-#-PZ_(?:CON|EXT)\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID block) ],
		OUTPUT_BLOCK_NAME       => 'SCANBTS_ADD',
		OUTPUT_FILENAME_START   => 'SCANBTS_ADD',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

#---------------------------------------------------------------------------------------------------------------------
# BTS_AGG_TO_BSC	
#---------------------------------------------------------------------------------------------------------------------

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join SCANBTS files for BTS_AGG_TO_BSC accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ\.pif$',],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID) ],
		OUTPUT_BLOCK_NAME       => 'BTS_AGG_TO_BSC',
		OUTPUT_FILENAME_START   => 'SCAN_BTS_AGG_TO_BSC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join SCANBTS_EXTENDED files for BTS_AGG_TO_BSC accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTS_EXTENDED-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID) ],
		OUTPUT_BLOCK_NAME       => 'BTS_AGG_TO_BSC',
		OUTPUT_FILENAME_START   => 'EXT_BTS_AGG_TO_BSC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join SCANBTS_CONCENTRIC files for BTS_AGG_TO_BSC accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTS_CONCENTRIC-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID) ],
		OUTPUT_BLOCK_NAME       => 'BTS_AGG_TO_BSC',
		OUTPUT_FILENAME_START   => 'CON_BTS_AGG_TO_BSC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for BTS_AGG_TO_BSC accumulation',
		INPUT_FILE_DESCRIPTION  => ['^.+_(BTS_AGG_TO_BSC-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID block) ],
		OUTPUT_BLOCK_NAME       => 'BTS_AGG_TO_BSC',
		OUTPUT_FILENAME_START   => 'END_BTS_AGG_TO_BSC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},

	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'For SCANBTS, split file by MEBUSTCH 1-2',
        INPUT_FILE_DESCRIPTION => ['^END_BTS_AGG_TO_BSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$', ],
        SPLIT_CNAMES => {
           'AGG' => ['(^MEBUSTCH_[1-9]$|^MEBUSTCH_10$)'],
        },
		ONLY_INSERT  => [ qw(BSS_ID BSC_ID BTSM_ID BTS_ID block) ],
        PRODUCE_PIF  => 'True',
    },
	
	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Change the counter name in SCANBTS before accumulation for BTS_AGG_TO_BSC',
        INPUT_FILE_DESCRIPTION  => ['^END_BTS_AGG_TO_BSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-AGG-#-FSC\.pif$', ],                                 
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
            if($c_ref->{block} eq 'SCANBTS')
			{
				$c_ref->{MEBUSTCH1} = $c_ref->{MEBUSTCH_1};
				$c_ref->{MEBUSTCH2} = $c_ref->{MEBUSTCH_2};
			}
			elsif($c_ref->{block} eq 'CON')
			{
				$c_ref->{MEBUSTCH1} = $c_ref->{MEBUSTCH_3};
				$c_ref->{MEBUSTCH2} = $c_ref->{MEBUSTCH_4};
				$c_ref->{MEBUSTCH3} = $c_ref->{MEBUSTCH_5};
				$c_ref->{MEBUSTCH4} = $c_ref->{MEBUSTCH_6};
			}
			elsif($c_ref->{block} eq 'EXT')
			{
				$c_ref->{MEBUSTCH1} = $c_ref->{MEBUSTCH_7};
				$c_ref->{MEBUSTCH2} = $c_ref->{MEBUSTCH_8};
				$c_ref->{MEBUSTCH3} = $c_ref->{MEBUSTCH_9};
				$c_ref->{MEBUSTCH4} = $c_ref->{MEBUSTCH_10};
			}
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
		REDUNDANT_DATA_COUNTERS    => ['MEBUSTCH_1','MEBUSTCH_2','MEBUSTCH_3','MEBUSTCH_4','MEBUSTCH_5','MEBUSTCH_6','MEBUSTCH_7','MEBUSTCH_8','MEBUSTCH_9','MEBUSTCH_10'],
        PRODUCE_PIF                => 'True',
    },

	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate',
		INPUT_FILE_DESCRIPTION  => [ '^END_BTS_AGG_TO_BSC-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-AGG-#-FSC-#-PZ\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID' ],
		OUTPUT_BLOCK_NAME       => 'BTS_AGG_TO_BSC',
		REDUNDANT_DATA_COUNTERS => [qw(BTSM_ID BTS_ID block)],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT          => "LIF_Writer",
	},

#---------------------------------------------------------------------------------------------------------------------
# Aggregation for SCANBTSOHOI, SCANBTSIHO, SCANBTSOHON, SCANBTSOHOS
#---------------------------------------------------------------------------------------------------------------------
	
	{
		RULE_TYPE               => 'AGGREGATE_LINE',
		RULE_DESC               => 'Line aggregation for SCANBTSOHOI',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSOHOI-#-.+-#-J-#-PZ\.pif$' ],
		REDUNDANT_DATA_COUNTERS => [],
		DEFAULT_NULL_VALUE      => '',
		COUNTER_GROUPS => {
			C5_0_Total => '(^SOUINIRH_[1-9]$|^SOUINIRH_[1-3][0-9]$|^SOUINIRH_4[0-8]$)',
			C5_1_Total => '(^AOUINIRH_[1-9]$|^AOUINIRH_[1-3][0-9]$|^AOUINIRH_4[0-8]$)',
			C5_2_Total => '(^UNINHOIE_[1-9]$|^UNINHOIE_[1-3][0-9]$|^UNINHOIE_4[0-8]$)',
		}
	},

	{
		RULE_TYPE               => 'AGGREGATE_LINE',
		RULE_DESC               => 'Line aggregation for SCANBTSIHO',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSIHO-#-.+-#-J-#-PZ\.pif$', ],
		REDUNDANT_DATA_COUNTERS => [],
		DEFAULT_NULL_VALUE      => '',
		COUNTER_GROUPS => {
			C3_0_Total => '(^SININIRH_[1-9]$|^SININIRH_[1-3][0-9]$|^SININIRH_4[0-8]$)',
			C3_1_Total => '(^AININIRH_[1-9]$|^AININIRH_[1-3][0-9]$|^AININIRH_4[0-8]$)',
		}
	},
	
	{
		RULE_TYPE               => 'AGGREGATE_LINE',
		RULE_DESC               => 'Line aggregation for SCANBTSOHON',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSOHON-#-.+-#-J-#-PZ\.pif$', ],
		REDUNDANT_DATA_COUNTERS => [],
		DEFAULT_NULL_VALUE      => '',
		COUNTER_GROUPS => {
			C6_0_Total => '(^ATINBHDO_[1-9]$|^ATINBHDO_1[0-1]$)',
			C6_1_Total => '(^SUINBHDO_[1-9]$|^SUINBHDO_1[0-1]$)',
			C6_2_Total => '(^NRUNINHD_[1-9]$|^NRUNINHD_1[0-1]$)',
		}
	},
	
	{
		RULE_TYPE               => 'AGGREGATE_LINE',
		RULE_DESC               => 'Line aggregation for SCANBTSOHOS',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSOHOS-#-.+-#-J-#-PZ\.pif$', ],
		REDUNDANT_DATA_COUNTERS => [],
		DEFAULT_NULL_VALUE      => '',
		COUNTER_GROUPS => {
			C12_0_Total => '(^ATOISHDO_[1-9]$|^ATOISHDO_1[0-1]$)',
			C12_1_Total => '(^SUOISHDO_[1-9]$|^SUOISHDO_1[0-1]$)',
			C12_2_Total => '(^UNOISHDO_[1-9]$|^UNOISHDO_1[0-1]$)',
		}
	},

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for SCANBTSOHOI_AGGREGATE accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTSOHOI-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-AL\.pif$',],
		COUNTERS_TO_JOIN_ON     => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_BTSM_ID ADJ_BTS_ID ) ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSOHOI_AGGREGATE',
		OUTPUT_FILENAME_START   => 'SCANBTSOHOI_AGGREGATE',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for SCANBTSIHO_AGGREGATE accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTSIHO-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-AL\.pif$',],
		COUNTERS_TO_JOIN_ON     => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_BTSM_ID ADJ_BTS_ID ) ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSIHO_AGGREGATE',
		OUTPUT_FILENAME_START   => 'SCANBTSIHO_AGGREGATE',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for SCANBTSOHON_AGGREGATE accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTSOHON-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-AL\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_TGTBTS_NO ) ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSOHON_AGGREGATE',
		OUTPUT_FILENAME_START   => 'SCANBTSOHON_AGGREGATE',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for SCANBTSOHOS_AGGREGATE accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTSOHOS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ-#-AL\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw( BSC_ID BTSM_ID BTS_ID ADJ_BSC_ID ADJ_FDD_NO ) ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSOHOS_AGGREGATE',
		OUTPUT_FILENAME_START   => 'SCANBTSOHOS_AGGREGATE',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},

	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate for SCANBTSOHOI_AGGREGATE',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSOHOI_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID','BTSM_ID','BTS_ID','CI' ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSOHOI_AGGREGATE',
		REDUNDANT_DATA_COUNTERS => [qw( ADJ_BSC_ID ADJ_BTSM_ID ADJ_BTS_ID ADJ_CI)],
		OLD_COUNTER_NAMES       => ['C5_0_Total','C5_1_Total','C5_2_Total'],
		NEW_COUNTER_NAMES       => ['C5_0_Total_OverTarget','C5_1_Total_OverTarget','C5_2_Total_OverTarget'],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
	},

	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate for SCANBTSIHO_AGGREGATE',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSIHO_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID','BTSM_ID','BTS_ID','CI' ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSIHO_AGGREGATE',
		REDUNDANT_DATA_COUNTERS => [qw( ADJ_BSC_ID ADJ_BTSM_ID ADJ_BTS_ID ADJ_CI)],
		OLD_COUNTER_NAMES       => ['C3_0_Total','C3_1_Total'],
		NEW_COUNTER_NAMES       => ['C3_0_Total_OverTarget','C3_1_Total_OverTarget'],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
		{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate for SCANBTSOHON_AGGREGATE',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSOHON_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID','BTSM_ID','BTS_ID','CI' ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSOHON_AGGREGATE',
		REDUNDANT_DATA_COUNTERS => [qw( ADJ_BSC_ID ADJ_TGTBTS_NO ADJ_CI)],
		OLD_COUNTER_NAMES       => ['C6_0_Total','C6_1_Total','C6_2_Total'],
		NEW_COUNTER_NAMES       => ['C6_0_Total_OverTarget','C6_1_Total_OverTarget','C6_2_Total_OverTarget'],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate for SCANBTSOHOS_AGGREGATE',
		INPUT_FILE_DESCRIPTION  => [ '^SCANBTSOHOS_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID','BTSM_ID','BTS_ID','CI' ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSOHOS_AGGREGATE',
		REDUNDANT_DATA_COUNTERS => [qw( ADJ_BSC_ID ADJ_FDD_NO ADJ_CI)],
		OLD_COUNTER_NAMES       => ['C12_0_Total','C12_1_Total','C12_3_Total'],
		NEW_COUNTER_NAMES       => ['C12_0_Total_OverTarget','C12_1_Total_OverTarget','C12_3_Total_OverTarget'],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Create counters for SCANBTSOHOI_AGGREGATE',
        INPUT_FILE_DESCRIPTION  => ['^SCANBTSOHOI_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-SCANBTSOHOI_AGGREGATE-#-A\.pif$',],                                   
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;
			my $i;
			foreach $i ( 0 .. 48 )
			{
				unless(exists $c_ref->{"SOUINIRH_$i"})
				{	$c_ref->{"SOUINIRH_$i"} = 0;	}
				unless(exists $c_ref->{"AOUINIRH_$i"})
				{	$c_ref->{"AOUINIRH_$i"} = 0;	}
			}
			foreach $i ( 0 .. 12 )
			{
				unless(exists $c_ref->{"UNINHOIE_$i"})
				{	$c_ref->{"UNINHOIE_$i"} = 0;	}
			}
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ_CON',
        PRODUCE_PIF                => 'True',
		OUTPUT_FORMAT              => 'LIF_Writer',
    },
	
#---------------------------------------------------------------------------------------------------------------------
# Aggregation for SCANGPRS
#---------------------------------------------------------------------------------------------------------------------

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for SCANGPRS_AGGREGATE accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANGPRS-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID PCUN PTPPKF_ID CELLTYPE CONCELL CI ) ],
		OUTPUT_BLOCK_NAME       => 'SCANGPRS_AGGREGATE',
		OUTPUT_FILENAME_START   => 'SCANGPRS_AGGREGATE',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},

	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'Split file by NALIPDCH counters',
        INPUT_FILE_DESCRIPTION => ['^SCANGPRS_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
        SPLIT_CNAMES => {
           'AGG' => ['^NALIPDCH_[1-3]$'],
        },
        ONLY_INSERT  => [ qw( BSC_ID BTSM_ID BTS_ID PCUN PTPPKF_ID CELLTYPE CONCELL CI ) ],
        PRODUCE_PIF  => 'True',
    },

	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate for NALIPDCH counters ',
		INPUT_FILE_DESCRIPTION  => [ '^SCANGPRS_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-AGG-#-FSC\.pif$'],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID' ],
		OUTPUT_BLOCK_NAME       => 'SCANGPRS_AGGREGATE',
		REDUNDANT_DATA_COUNTERS => [qw(BTSM_ID BTS_ID PCUN PTPPKF_ID CELLTYPE CONCELL CI)],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

#---------------------------------------------------------------------------------------------------------------------
# Aggregation for SCANCHAN
#---------------------------------------------------------------------------------------------------------------------

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join for SCANCHAN_AGGREGATE accumulation',
		INPUT_FILE_DESCRIPTION  => ['^(SCANCHAN-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d+-#-J-#-PZ\.pif$',	],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID BTS_ID PCUN PTPPKF_ID CELLTYPE CONCELL CI ) ],
		OUTPUT_BLOCK_NAME       => 'SCANCHAN_AGGREGATE',
		OUTPUT_FILENAME_START   => 'SCANCHAN_AGGREGATE',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT           => 0,
	},

	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'Split file by PWRUPDW counters',
        INPUT_FILE_DESCRIPTION => ['^SCANCHAN_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
        SPLIT_CNAMES => {
           'AGG' => ['^PWRUPDW_\d+$'],
        },
        ONLY_INSERT  => [ qw( BSC_ID BTSM_ID BTS_ID PCUN PTPPKF_ID CELLTYPE CONCELL CI ) ],
        PRODUCE_PIF  => 'True',
    },

	{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Perform calculation for PWRUPDW counters',
        INPUT_FILE_DESCRIPTION  => ['^SCANCHAN_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-AGG-#-FSC\.pif$',],                                   
        DATA_COUNTERS_OP        => sub
        {
            my $c_ref = shift;        
            my %range_to_cname = (
                64  => 'MeanRxLvUL', # Counter range   1 to 64
                72  => 'MeanRxQuUL', # Counter range  65 to 72
                136 => 'MeanRxLvDL', # Counter range  73 to 136
                144 => 'MeanRxQuDL', # Counter range 136 to 144
            );            
            my ($i,$j);
            my $lower_bound = 1;
            my $upper_bound = 0;
            my $sum = 0;
            my $mul = 0;
            
            foreach $i ( 64, 72, 136, 144 ) {
                $upper_bound = $i;           
                $sum = 0;
                $mul = 0;
                foreach $j ( $lower_bound .. $upper_bound ) {
                    if ( exists $c_ref->{"PWRUPDW_$j"} ) {                    
                        $sum += $c_ref->{"PWRUPDW_$j"};
                        $mul += ($j - $lower_bound + 1) * $c_ref->{"PWRUPDW_$j"};                   
                    }
                }
                $c_ref->{"$range_to_cname{$i}"} = $sum;
                # Prevent division by 0 error
                if ( $sum != 0 ) {
                    $c_ref->{"$range_to_cname{$i}"} = sprintf("%0.2f", ($mul / $sum)); # Round to 2 decimal places
                }
                $lower_bound = $upper_bound + 1;
            }
            
            return 0;
        },
        FILENAME_SUFFIX            => 'PZ',
        PRODUCE_PIF                => 'True',
    },
	
	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate PWRUPDW counters',
		INPUT_FILE_DESCRIPTION  => [ '^SCANCHAN_AGGREGATE-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-AGG-#-FSC-#-PZ\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID','BTSM_ID','BTS_ID','CI' ],
		OUTPUT_BLOCK_NAME       => 'SCANCHAN_AGGREGATE',
		REDUNDANT_DATA_COUNTERS => [qw(TRX_ID CHANNEL_ID)],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
#---------------------------------------------------------------------------------------------------------------------
# Aggregation for SCANFBTSM up to BSC level
#---------------------------------------------------------------------------------------------------------------------
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANFBTSM',
		INPUT_FILE_DESCRIPTION  => ['^(SCANFBTSM-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANFBTSM',
		OUTPUT_FILENAME_START   => 'SCANFBTSM',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'For SCANBTS_CONCENTRIC, split file by MEBUSTCH 3-6',
        INPUT_FILE_DESCRIPTION => ['^SCANFBTSM-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J\.pif$',],
        SPLIT_CNAMES => {
           'AGG' => ['^IFRMABSC_\d+$'],
        },
        ONLY_INSERT  => [ qw(BSS_ID BSC_ID BTSM_ID) ],
        PRODUCE_PIF  => 'True',
    },
	
	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Accumulate IFRMABSC counters',
		INPUT_FILE_DESCRIPTION  => [ '^SCANFBTSM-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-AGG-#-FSC\.pif$',],
		COUNTERS_TO_SORT_ON     => [ 'BSC_ID' ],
		OUTPUT_BLOCK_NAME       => 'SCANFBTSM_BSC',
		REDUNDANT_DATA_COUNTERS => [qw(BTSM_ID)],
		NON_ADDITIVE_COUNTERS	=> ['BSS_ID'],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
#----------------------------------------------------------------------------------------------------------
# Join the Initial PIFs of the following blocks
#----------------------------------------------------------------------------------------------------------
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANDPC',
		INPUT_FILE_DESCRIPTION  => ['^(SCANDPC-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID DPC_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANDPC',
		OUTPUT_FILENAME_START   => 'SCANDPC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANSS7L',
		INPUT_FILE_DESCRIPTION  => ['^(SCANSS7L-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID LINKSET) ],
		OUTPUT_BLOCK_NAME       => 'SCANSS7L',
		OUTPUT_FILENAME_START   => 'SCANSS7L',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANNSVC',
		INPUT_FILE_DESCRIPTION  => ['^(SCANNSVC-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID NSVC_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANNSVC',
		OUTPUT_FILENAME_START   => 'SCANNSVC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANATMVC',
		INPUT_FILE_DESCRIPTION  => ['^(SCANATMVC-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID ATMVCC_ID ATMVPC_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANATMVC',
		OUTPUT_FILENAME_START   => 'SCANATMVC',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANATMVP',
		INPUT_FILE_DESCRIPTION  => ['^(SCANATMVP-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID ATMVPC_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANATMVP',
		OUTPUT_FILENAME_START   => 'SCANATMVP',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Join initial pif of SCANBTSM',
		INPUT_FILE_DESCRIPTION  => ['^(SCANBTSM-#-\d+-#-\d+\w+\d{4}-#-\d{2}:\d{2})-#-\d{8}\.\d{4}-#-.+-#-(?:\d+-#-)?I\.pif$'],
		COUNTERS_TO_JOIN_ON     => [ qw(BSC_ID BTSM_ID) ],
		OUTPUT_BLOCK_NAME       => 'SCANBTSM',
		OUTPUT_FILENAME_START   => 'SCANBTSM',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(ENDDATE ENDTIME) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
		PRODUCE_PIF             => 'TRUE',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Output all required LIFs',
        INPUT_FILE_DESCRIPTION => [
		'^SCANCHAN-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ\.pif$',
        '^SCANGPRS-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ\.pif$',				  
		'^SCANBTSOHOI-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ-#-AL\.pif$',
		'^SCANBTSIHO-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ-#-AL\.pif$',	
		'^SCANBTSOHON-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ-#-AL\.pif$',
		'^SCANBTSOHOS-#-\d+\w+\d{4}-#-\d{2}:\d{2}-#-\d+-#-J-#-PZ-#-AL\.pif$',					  					  
		'^SCANTRX-#-.+-#-J-#-PZ\.pif$',
		'^SCANBTSE-#-.+-#-J-#-PZ\.pif$',
		'^SCANBTS-#-.+-#-J-#-PZ\.pif$',
		'^SCANBTS_STANDARD-#-.+-#-J-#-PZ\.pif$',
								  ],               
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT          => "LIF_Writer"
    }, 
#-------------------------------------------------------------------------------
# END: Performance post parser
#-------------------------------------------------------------------------------

);  

#-------------------------------------------------------------------------------

sub postparser_config {
    return \@rules;
}

1;
